'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the praiseworthy ' + chalk.red('generator-sae-generator') + ' generator!'
    ));

    var prompts = [{
      type: 'confirm',
      name: 'bootstrap',
      message: 'Would you like to enable Bootstrap?',
      default: true
    }, {
      type: 'confirm',
      name: 'bootstrapScripts',
      message: 'Would you like to enable Bootstrap Scripts?',
      default: true
    }];

    this.prompt(prompts, function (props) {
      this.props = props;
      console.log(this.props.bootstrap);
      // To access props later use this.props.someOption;

      done();
    }.bind(this));
  },

  writing: function () {
    if (this.props.bootstrap) {
      this.fs.copy(
        this.templatePath('bootstrap/css/bootstrap.min.css'),
        this.destinationPath('css/bootstrap.min.css')
      );
      this.fs.copy(
        this.templatePath('bootstrap/fonts/*'),
        this.destinationPath('fonts/')
      );
      var bootstrapCSS = '<link rel="stylesheet" href="css/bootstrap.min.css">';
    }
    if (this.props.bootstrapScripts) {
      this.fs.copy(
        this.templatePath('bootstrap/js/bootstrap.min.js'),
        this.destinationPath('js/bootstrap.min.js')
      );
      var bootstrapJS = '<script src="js/bootstrap.min.js"></script>';
    }
    this.fs.copyTpl(
      this.templatePath('index.html'),
      this.destinationPath('index.html'),
      { bootstrapCSS: bootstrapCSS,
        bootstrapJS: bootstrapJS }
    );
    this.fs.copy(
      this.templatePath('style.css'),
      this.destinationPath('css/style.css')
    );
  },

  install: function () {
    this.installDependencies();
  }
});
